@@ -30,7 +30,7 @@ QUrl FIFiles::getUrl()
 	QString requestChannelCode = _channelCodeMap[_requestChannel];
 
 	if ( !_useLocal )
-		url.setUrl(QString("http://www.xmltvepg.be/rytecxmltvnordic.gz?APP=SHOWTIME"));
+		url.setUrl(QString("http://www.xmltvepg.nl/rytecxmltvnordic.gz?APP=SHOWTIME"));
 	else
 		url.setPath(QString(""));
 
