@@ -30,7 +30,7 @@ QUrl FRFiles::getUrl()
 	QString requestChannelCode = _channelCodeMap[_requestChannel];
 
 	if ( !_useLocal )
-		url.setUrl(QString("http://www.xmltvepg.be/rytecxmltvcsat.gz?APP=SHOWTIME") );
+		url.setUrl(QString("http://www.xmltvepg.nl/rytecxmltvcsat.gz?APP=SHOWTIME") );
 	else
 		url.setPath(QString(""));
 
