@@ -37,7 +37,7 @@ public:
 	QStringList getRegionList()
 	{
 		QStringList list;
-		list << "UK" << "AU" << "NZ" << "SE" << "DE" << "FR" << "ES" << "IT" << "HR" << "SI" << "DK" << "NL" << "BE" << "NO" << "RU" << "MY" << "ZA" << "PL" << "FI" << "IE";
+		list << "UK" << "AU" << "NZ" << "SE" << "DE" << "FR" << "ES" << "IT" << "HR" << "SI" << "DK" << "NL" << "BE" << "NO" << "RU" << "MY" << "ZA" << "PL" << "FI" << "IE" << "SK" << "CZ";
 		return list;
 	}
 
@@ -64,6 +64,8 @@ private slots:
 	void setPL();
 	void setFI();
 	void setIE();
+	void setSK();
+	void setCZ();
 	void setRegion(QString region);
 
 signals:
