@@ -31,7 +31,7 @@ QUrl UKFiles::getUrl()
 	QString requestChannelCode = _channelCodeMap[_requestChannel];
 
 	if ( !_useLocal )
-		url.setUrl(QString("http://www.xmltvepg.be/rytecxmltvuk.gz?APP=SHOWTIME") );
+		url.setUrl(QString("http://www.xmltvepg.nl/rytecxmltvuk.gz?APP=SHOWTIME") );
 	else
 		url.setPath(QString(""));
 
